# Garage Ops

| Code   | [![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) |
| ------ | ------------------------------------------------------------ |
| Social | ![Twitter Follow](https://img.shields.io/twitter/follow/garageops?style=social) |


## Feedback

If you have general comments or want to ask a question, please [create a discussion on GitHub](https://github.com/garageops/garageops/discussions). If you've found an issue or want to suggest a new feature, please [open an issue on GitHub](https://github.com/garageops/garageops/issues).

## Contributing

Contributions are welcome!

### Pre-commit

This repository uses [pre-commit](https://pre-commit.com/) to catch simple issues before they are checked into the repository.

Before contributing, please make sure to [install pre-commit](https://pre-commit.com/#install) and then run `pre-commit install` inside this repository to set up the git hook scripts. Once the git hooks are installed, they will be run automatically before each `git commit`.

See [.pre-commit-config.yaml](.pre-commit-config.yaml) for a full list of the git hooks that are run.

## License Information

This repository is compliant with version 3.0 of the [REUSE Specification](https://reuse.software/spec/).

License files are contained in the [LICENSES/](LICENSES/) directory and additional license & copyright information can be found in [.reuse/dep5](.reuse/dep5).

Run the following for detailed copyright & license information on individual files:

```sh
pip install reuse
reuse spdx
```
